@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::MANWAR;
 
-$Dist::Zilla::PluginBundle::MANWAR::VERSION = '0.02';
+$Dist::Zilla::PluginBundle::MANWAR::VERSION = '0.03';
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -59,7 +59,7 @@ Dist::Zilla::PluginBundle::MANWAR - Dist::Zilla plugins for manwar.
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
@@ -77,6 +77,11 @@ This is the plugin bundle that MANWAR uses.  It's equivalent to:
     [MetaJSON]
     [MetaYAML]
 
+    [MetaProvides::Package]
+    inherit_version = 0
+    inherit_missing = 0
+    meta_noindex = 1
+
     [PruneFiles]
     filenames = dist.ini
 
